// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import XCTest
import os.log
@testable import Logger

final class MultiLoggerTests: XCTestCase {

    func testMultiLogger() {
        let singleLogger1 = TestLogger()
        let singleLogger2 = TestLogger()

        let multiLogger = MultiLogger(loggers: [singleLogger1, singleLogger2])

        multiLogger.debug("Invoke all the loggers!")
        multiLogger.info("Invoke all the loggers!")
        multiLogger.warning("Invoke all the loggers!")
        multiLogger.error("Invoke all the loggers!")
        multiLogger.critical("Invoke all the loggers!")

        XCTAssertTrue(singleLogger1.isFulfilled())
        XCTAssertTrue(singleLogger2.isFulfilled())
    }

    static var allTests = [
        ("testMultiLogger", testMultiLogger)
    ]
}

class TestLogger : LoggerProtocol {
    var invoked: [String: Bool] = [
        LogLevel.debug.title: false,
        LogLevel.info.title: false,
        LogLevel.warning.title: false,
        LogLevel.error.title: false,
        LogLevel.critical.title: false
    ]

    // MARK: - Logger
    func log(_ message: String, at level: LogLevel, file: String, function: String, line: UInt, category: String?) {
        invoked[level.title] = true
    }

    func isFulfilled() -> Bool {
        invoked.allSatisfy({ $0.value })
    }
}
