// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import TIM
import TIMEncryptedStorage
import AppAuth

private let scopes = [OIDScopeOpenID, OIDScopeProfile]
private let testUrl = "https://oidc-test.hosted.trifork.com/auth/realms/gravid" 
private let prodUrl = "https://oidc.hosted.trifork.com/auth/realms/gravid"
private let clientIdMock = "gravidappmock"
private let clientId = "gravidapp"

extension TIMConfiguration {
    static func forBuildConfiguration(_ config: BuildConfiguration) -> TIMConfiguration {
        switch config {
        case .debug, .development, .testMock, .test:
            return TIMConfiguration(
                oidc: TIMOpenIDConfiguration(
                    issuer: URL(string: testUrl)!,
                    clientId: clientIdMock,
                    redirectUri: URL(string: "\(clientIdMock):/")!,
                    scopes: scopes
                ),
                keyService: TIMKeyServiceConfiguration(
                    realmBaseUrl: testUrl,
                    version: .v1
                )
            )
        case .release:
            return TIMConfiguration(
                oidc: TIMOpenIDConfiguration(
                    issuer: URL(string: prodUrl)!,
                    clientId: clientId,
                    redirectUri: URL(string: "\(clientId):/")!,
                    scopes: scopes
                ),
                keyService: TIMKeyServiceConfiguration(
                    realmBaseUrl: prodUrl,
                    version: .v1
                )
            )
        case .unknown:
            fatalError("Build config is not available.")
        }
    }
}
