// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import SwiftUI

final class Appearances {
    static func setup() {
        navigationBar()
        tabBar()
        segmentedControls()
        alertControllers()
    }

    private static let allStates: [UIControl.State] = [
        .disabled,
        .focused,
        .highlighted,
        .normal,
        .selected,
        .reserved
    ]

    private static func navigationBar() {
        UINavigationBar.appearance().backgroundColor = R.color.navigationBar()
        UINavigationBar.appearance().barTintColor = R.color.navigationBar()
        UINavigationBar.appearance().isTranslucent = false

        UINavigationBar.appearance().largeTitleTextAttributes = [
            NSAttributedString.Key.font: FontStyle.hero.font
        ]
        
        UINavigationBar.appearance().titleTextAttributes = [
            NSAttributedString.Key.font: FontStyle.h4.font
        ]

        let backImage = R.image.back()
        UINavigationBar.appearance().backIndicatorImage = backImage
        UINavigationBar.appearance().backIndicatorTransitionMaskImage = backImage
        UINavigationBar.appearance().tintColor = R.color.text()

        allStates.forEach { (state: UIControl.State) in
            UIBarButtonItem.appearance().setTitleTextAttributes([
                NSAttributedString.Key.font: FontStyle.body.font,
                NSAttributedString.Key.foregroundColor: R.color.text() as Any
            ], for: state)
        }
    }

    private static func tabBar() {
        UITabBar.appearance().isTranslucent = false
    }

    private static func segmentedControls() {
        // The only way to style a `Picker` with `SegmentedPickerStyle` at the moment...
        // This should be changed in the future, when Apple hopefully allows another way to do it through SwiftUI
        allStates.forEach { (state: UIControl.State) in
            UISegmentedControl.appearance().setTitleTextAttributes([
                NSAttributedString.Key.font: state == UIControl.State.selected ? FontStyle.smallBold.font : FontStyle.small.font,
                NSAttributedString.Key.foregroundColor: R.color.text() as Any
            ], for: state)
        }
    }

    private static func alertControllers() {
        UIView.appearance(whenContainedInInstancesOf: [UIAlertController.self]).tintColor = R.color.primary()
    }
}
