// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit

struct FontStyle {
    let font: UIFont
    let textStyle: UIFont.TextStyle
    let lineSpacing: CGFloat?
    let letterSpacing: CGFloat?

    init(font: UIFont, textStyle: UIFont.TextStyle, lineSpacing: CGFloat? = nil, letterSpacing: CGFloat? = nil) {
        self.font = font
        self.textStyle = textStyle
        self.lineSpacing = lineSpacing
        self.letterSpacing = letterSpacing
    }

    func requiresAttributedString() -> Bool {
        lineSpacing == nil || letterSpacing == nil
    }

    func scaledFont() -> UIFont {
        let fontMetrics: UIFontMetrics
        if textStyle.rawValue.starts(with: "UICT") {
            fontMetrics = UIFontMetrics(forTextStyle: textStyle)
        } else {
            fontMetrics = UIFontMetrics.default
        }
        return fontMetrics.scaledFont(for: font)
    }
}

extension FontStyle {

    // MARK: - Headers
    static let hero = FontStyle(
        font: R.font.ptSansBold(size: 32)!,
        textStyle: .largeTitle
    )

    static let h1 = FontStyle(
        font: R.font.ptSansBold(size: 24)!,
        textStyle: .title1
    )

    static let h2 = FontStyle(
        font: R.font.ptSansBold(size: 20)!,
        textStyle: .title2
    )

    static let h3 = FontStyle(
        font: R.font.ptSansBold(size: 18)!,
        textStyle: .title3
    )

    static let h4 = FontStyle(
        font: R.font.ptSansBold(size: 16)!,
        textStyle: .headline
    )

    static let h5 = FontStyle(
        font: R.font.ptSansBold(size: 12)!,
        textStyle: .subheadline
    )

    // MARK: - Text
    static let body = FontStyle(
        font: R.font.ptSansRegular(size: 16.0)!,
        textStyle: .body
    )

    static let small = FontStyle(
        font: R.font.ptSansRegular(size: 14.0)!,
        textStyle: .body
    )

    static let smallBold = FontStyle(
        font: R.font.ptSansBold(size: 14.0)!,
        textStyle: .body
    )

    static let info = FontStyle(
        font: R.font.ptSansRegular(size: 12.0)!,
        textStyle: .body
    )

    // MARK: - Custom controls
    static let button = FontStyle(
        font: R.font.ptSansBold(size: 16)!,
        textStyle: .callout
    )

    static let keyboard = FontStyle(
        font: R.font.titilliumWebLight(size: 25)!,
        textStyle: .callout
    )

}
