// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import MaternityData

struct AppointmentDetailMeasurementsView: View {

    let allFetusesObservations: [[Observation]]
    let motherObservations: [Observation]

    var hasResults: Bool {
        !allFetusesObservations.isEmpty || !motherObservations.isEmpty
    }

    var body: some View {
        VStack(alignment: .leading) {
            if hasResults {
                if !allFetusesObservations.isEmpty {
                    ForEach(allFetusesObservations.indices) { index in
                        let fetusObservations = allFetusesObservations[index]

                        AppointmentDetailMeasurementsTable(
                            title: fetusName(for: fetusObservations),
                            observations: fetusObservations
                        )
                        .padding(.bottom)
                    }
                }
                if !motherObservations.isEmpty {
                    AppointmentDetailMeasurementsTable(
                        title: R.string.localizable.appointment_details_measurement_mother(),
                        observations: motherObservations
                    )
                }
            } else {
                EmptyStateView(
                    title: R.string.localizable.appointment_details_measurement_empty_title(),
                    text: R.string.localizable.appointment_details_measurement_empty_description()
                )
            }
        }
    }

    private func fetusName(for fetusObservations: [Observation]) -> String {
        let name: String
        if let fetusName = fetusObservations.first?.fetus, allFetusesObservations.count > 1 {
            name = fetusName
        } else {
            name = R.string.localizable.appointment_details_measurement_child()
        }
        return name
    }
}

#if DEBUG
struct AppointmentDetailMeasurementsView_Previews: PreviewProvider {
    static let observations = loadPreviewCarePlans()
        .flatMap { $0.activities }
        .first!
        .observations

    static var previews: some View {
        ScrollView {
            AppointmentDetailMeasurementsView(
                allFetusesObservations: observations.fetusesObservations,
                motherObservations: observations.motherObservations
            )
        }

        AppointmentDetailMeasurementsView(
            allFetusesObservations: [],
            motherObservations: observations.motherObservations
        )
        .background(R.color.viewBackground.color())
        .environment(\.colorScheme, .dark)

        AppointmentDetailMeasurementsView(
            allFetusesObservations: [],
            motherObservations: []
        )
    }
}
#endif
