// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct AppointmentDetailPlannedValues: View {
    let date: Date
    let location: String
    let practitioner: String
    let phoneNumber: String?

    private var deviceSupportsCalls: Bool {
        UIApplication.shared.canOpenPhoneUrl()
    }

    var body: some View {
        VStack(
            alignment: .leading,
            spacing: Metrics.Spacing.appointmentsDisplayValuesSpacing) {
            AppointmentDetailValueDisplay(
                title: R.string.localizable.appointment_details_date_label(),
                value: Text(AppointmentsView.dateFormatter.string(from: date)).applyTextStyle(fontStyle: .body)
            )
            AppointmentDetailValueDisplay(
                title: R.string.localizable.appointment_time_label(),
                value: Text(AppointmentsView.timeFormatter.string(from: date)).applyTextStyle(fontStyle: .body)
            )
            AppointmentDetailValueDisplay(
                title: R.string.localizable.appointment_location_label(),
                value: Text(location).applyTextStyle(fontStyle: .body)
            )
            AppointmentDetailValueDisplay(
                title: R.string.localizable.appointment_at_label(),
                value: Text(practitioner).applyTextStyle(fontStyle: .body)
            )
            if let phoneNumber = phoneNumber {
                Button(action: {
                    UIApplication.shared.callPhoneNumber(phoneNumber: phoneNumber)
                }, label: {
                    AppointmentDetailValueDisplay(
                        title: R.string.localizable.appointment_details_contact_label(),
                        value: HStack {
                            Image(uiImage: R.image.phone()!)
                            Text(phoneNumber)
                                .applyTextStyle(
                                    fontStyle: .body,
                                    textColor: deviceSupportsCalls ? R.color.primary.color() : R.color.text.color()
                                )
                        }
                    )
                }).disabled(!deviceSupportsCalls)
            }
        }
    }
}

struct AppointmentDetailPlannedValues_Previews: PreviewProvider {
    static var previews: some View {
        AppointmentDetailPlannedValues(
            date: Date(),
            location: "Europaplads 2, 1., 8000 Aarhus C",
            practitioner: "Dr. Trifork",
            phoneNumber: "88 88 88 88"
        )
    }
}
