// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct ActivityMonthsView: View {
    let months: [CareplanActivitiesMonth]
    let color: Color
    
    var body: some View {
        ForEach(months) { (month: CareplanActivitiesMonth) in
            MonthSeparatorView(color: color,
                               date: month.activities.first?.plannedTime?.from)

            ForEach(month.activities) { activity in
                HStack {
                    VStack(alignment: .leading, spacing: 0) {
                        VerticalLineView(color: color)
                            .frame(height: 24)

                        AppointmentDotView(color: R.color.primary.color())

                        VerticalLineView(color: color)
                    }
                    .foregroundColor(color)
                    NavigationLink(
                        destination: AppointmentDetailView(activity: activity),
                        label: {
                            ActivityCardView(activity: activity)
                                .padding(.trailing)
                                .padding(.bottom)
                        })
                        .foregroundColor(R.color.text.color())
                }
            }
        }
    }
}

#if DEBUG
struct ActivityMonthsView_Previews: PreviewProvider {
    private static let carePlanActivitiesMonth = CareplanActivitiesMonth(month: 10,
                                                                      activities: loadFinishedActivities())

    static var previews: some View {
        ScrollView {
            VStack(spacing: 0) {
                ActivityMonthsView(months: [carePlanActivitiesMonth], color: .purple)
            }
        }
    }
}
#endif
