// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct DashedTimelineView: View {

    /// Color of the line and dot.
    let lineColor: Color

    /// If `true` the dashed line will come before the dot and the solid after. If false, vice versa.
    let isEndDashed: Bool

    private let lineHeight: CGFloat = 24

    var body: some View {
        VStack(alignment: .center, spacing: 0, content: {

            if isEndDashed {
                line
            } else {
                dashedLine
            }

            Circle()
                .frame(size: 12)

            if isEndDashed {
                dashedLine
            } else {
                line
            }
        })
        .foregroundColor(lineColor)
    }

    private var dashedLine: some View {
        VLine()
            .stroke(style: StrokeStyle(lineWidth: Metrics.Sizes.timelineLineWidth, dash: [4]))
            .frame(width: Metrics.Sizes.timelineLineWidth, height: lineHeight)
    }

    private var line: some View {
        VLine()
            .stroke(style: StrokeStyle(lineWidth: Metrics.Sizes.timelineLineWidth))
            .frame(width: Metrics.Sizes.timelineLineWidth, height: lineHeight)
    }
}

struct DashedTimelineView_Previews: PreviewProvider {
    static var previews: some View {
        DashedTimelineView(lineColor: R.color.activitiesFinishedLine.color(), isEndDashed: true)
            .background(R.color.viewBackground.color())
            .environment(\.colorScheme, .dark)

        DashedTimelineView(lineColor: R.color.activitiesUnfinishedLine.color(), isEndDashed: false)
            .background(R.color.viewBackground.color())
            .environment(\.colorScheme, .dark)
    }
}
