// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import ChecklistData
import Combine
import ErrorData

struct ChecklistDetailItemList: View {
    var checklist: Checklist
    var toggleItemEvent: (ChecklistItem) -> AnyPublisher<Void, ServiceError>

    var body: some View {
        if #available(iOS 14, *) {
            // Had to use spacing instead of padding on content, to make it look right
            LazyVStack(spacing: Metrics.Spacing.narrowCardSpacing) {
                listContent()
            }
            .padding()
        } else {
            VStack(spacing: Metrics.Spacing.narrowCardSpacing) {
                listContent()
            }
        }
    }

    @ViewBuilder func listContent() -> some View {
        ForEach(checklist.items) { item in
            ChecklistDetailItemRow(
                item: item,
                toggleItemEvent: toggleItemEvent
            )
        }
    }
}

#if DEBUG
struct ChecklistDetailItemList_Previews: PreviewProvider {
    static var previews: some View {
        ChecklistDetailItemList(
            checklist: Checklist.previewList().first!,
            toggleItemEvent: { _ in
                Just(Void())
                    .setFailureType(to: ServiceError.self)
                    .eraseToAnyPublisher()

            }
        )
    }
}
#endif
