// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import ChecklistData

struct ChecklistDetailView: View {

    @ObservedObject var viewModel: ViewModel
    @EnvironmentObject var environmentStore: KnowledgeView.EnvironmentStore

    init(checklist: Checklist) {
        self.viewModel = ViewModel(checklist: checklist)
    }

    var body: some View {
        ScrollView {
            VStack {
                ChecklistDetailTopView(
                    title: viewModel.checklist.title,
                    infoText: viewModel.checklist.text,
                    progress: viewModel.checklist.progress,
                    completedItems: viewModel.checklist.completedItems,
                    numberOfItems: viewModel.checklist.totalItems
                )
                .padding()
                ChecklistDetailItemList(
                    checklist: viewModel.checklist,
                    toggleItemEvent: { (item: ChecklistItem) in
                        viewModel.toggleCheckItem(item)
                            .receiveOnMain()
                            .handleEvents(receiveOutput: { updatedItem in
                                environmentStore.updateChecklist(viewModel.checklist, checklistItem: updatedItem)
                            })
                            .handleEvents(
                                receiveCompletion: { completion in
                                    switch completion {
                                    case .failure(let error):
                                        viewModel.alertError = error
                                    case .finished: break
                                    }
                                })
                            .mapToVoid()
                            .eraseToAnyPublisher()
                    }
                )
            }
            .alert(for: $viewModel.alertError)
        }
        .navigationBarTitle(Text(R.string.localizable.checklist_title()), displayMode: .inline)
    }
}

#if DEBUG
struct ChecklistDetailView_Previews: PreviewProvider {
    static var previews: some View {
        ChecklistDetailView(checklist: Checklist.previewList().first!)
            .environmentObject(KnowledgeView.EnvironmentStore(checklists: Checklist.previewList()))
    }
}
#endif
