// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import LexiconData

struct LexiconDetailView: View {
    let lexicon : Lexicon

    private let dateFormatter: DateFormatter

    init(lexicon: Lexicon) {
        self.lexicon = lexicon
        self.dateFormatter = DateFormatter()
        self.dateFormatter.timeStyle = .none
        self.dateFormatter.dateStyle = .medium
    }

    var body: some View {
        ScrollView {
            VStack(alignment: .leading) {
                Text(lexicon.excerpt)
                    .applyTextStyle(fontStyle: .body)
                    .padding(.vertical)

                ForEach(lexicon.content) { article in
                    ArticleCard(article: article)
                }

                HStack {
                    Spacer()
                    Text(R.string.localizable.article_last_updated_on(dateFormatter.string(from: lexicon.lastUpdateDate)))
                        .applyTextStyle(fontStyle: .info, textColor: R.color.greyText.color())
                    Spacer()
                }
            }
            .padding()
        }
        .background(R.color.viewBackground.color())
        .navigationBarTitle(lexicon.title)
    }
}

struct LexiconDetailView_Previews: PreviewProvider {
    //swiftlint:disable line_length
    private static let mockLexicon = Lexicon(publicationDate: Date(),
                                             lastUpdateDate: Date().date(byAdding: .year, value: -90),
                                             id: UUID().uuidString,
                                             title: "Mad og Drikke",
                                             content: [],
                                             excerpt: "Er der noget bedre tidspunkt at begynde at spise sundere, end når du er gravid? At spise sundt hjælper til at fremme en sund graviditet og en god start i livet for dit barn. De fleste af os kan godt tåle at kaste et kritisk blik på vores spisevaner: Er der mon noget der kan gøres bedre?",
                                             categories: [],
                                             tags: [])
    static var previews: some View {
        NavigationView {
            LexiconDetailView(lexicon: mockLexicon)
        }
    }
}
