// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import LexiconData

struct LexiconListView: View {
    @ObservedObject private var viewModel: ViewModel

    private let category: LexiconData.Category
    
    init(category: LexiconData.Category) {
        self.category = category
        viewModel = ViewModel(category: category)
    }

    var body: some View {
        ScrollView {
            CompatibleVStack {
                LexiconListHeaderView(title: category.name,
                                      text: category.description,
                                      imageUrl: category.imageUrl)
                ForEach(viewModel.lexicons) { lexicon in
                    NavigationLink(
                        destination: LexiconDetailView(lexicon: lexicon),
                        label: {
                            LexiconCardView(lexicon: lexicon)
                        })
                }
            }
            .padding()
        }
        .background(R.color.viewBackground.color())
        .onAppear(perform: viewModel.fetchData)
        .navigationBarTitle(Text(""), displayMode: .inline)
    }
}

struct LexiconListView_Previews: PreviewProvider {
    private static let mockCategory = LexiconData.Category(id: UUID().uuidString,
                                                             imageUrl: URL(string: "https://via.placeholder.com/150")!,
                                                             name: "Uge for uge",
                                                             description: "Some description",
                                                             count: 5)
    static var previews: some View {
        LexiconListView(category: mockCategory)
    }
}
