// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import LexiconData

struct ArticleCard: View {
    let article: Article
    @State private var webViewHeight: CGFloat = 50
    @State private var isExpanded = false
    @State private var isLoading = true

    var body: some View {
        BasicCardView {
            VStack(alignment: .leading, spacing: 0) {
                Text(article.title)
                    .applyTextStyle(fontStyle: FontStyle.h3)
                    .padding(.horizontal)
                    .padding(.top)

                contentView
                    .padding(.horizontal)
                    .padding(.bottom)

                DefaultDivider()

                FoldingButton(isExpanded: $isExpanded)
            }
        }
    }

    @ViewBuilder private var contentView: some View {
        ZStack {
            HTMLView(dynamicHeight: $webViewHeight,
                     isLoading: $isLoading,
                     htmlFilePath: R.file.articleContentHtml()!,
                     html: article.content)
                .background(R.color.cardBackground.color())
            if !isExpanded {
                Rectangle()
                    .fill(Color.clear)
                    .background(LinearGradient(gradient: Gradient(colors: [
                        R.color.cardBackground.color(),
                        R.color.cardBackground.color().opacity(0.0)
                    ]), startPoint: .bottom, endPoint: .top))
            }

            if isLoading {
                HStack {
                    Spacer()
                    ActivityIndicatorView(isAnimating: isLoading,
                                          style: .medium,
                                          hidesWhenStopped: true)
                    Spacer()
                }
            }
        }
        .frame(height: isExpanded ? webViewHeight : 50)
    }
}

//swiftlint:disable line_length
struct ArticleCard_Previews: PreviewProvider {
    private static let mockArticle = Article(title: "Fordele ved det sunde",
                                             content: """
                                                        <p>Her er en lille guide med indhold</p><video width="320" height="240" controls>    <source src="movie.mp4" type="video/mp4">    <source src="movie.ogg" type="video/ogg">        Din browser understøtter ikke video</video><p>Der er også tekst efter videoen</p>

                                                        """)

    static var previews: some View {
        ArticleCard(article: mockArticle)
    }
}
