// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct LexiconCardVStack: View {
    let title: String
    let text: String
    let itemsCount: Int?
    
    var body: some View {
        VStack(alignment: .leading) {
            Text(title)
                .applyTextStyle(fontStyle: .h2)
            
            Text(text)
                .applyTextStyle(fontStyle: .body)
                .lineLimit(2)
            
            HStack {
                if let itemsCount = itemsCount {
                    Text(itemsCount == 1 ?
                            R.string.localizable.articles_count_singular(itemsCount.description) :
                            R.string.localizable.articles_count_plural(itemsCount.description))
                        .applyTextStyle(fontStyle: .info, textColor: R.color.greyText.color())
                }
                
                Spacer()
                
                ChevronRightView()
            }
        }
    }
}

struct LexiconCardVStack_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            LexiconCardVStack(title: "Undersøgelser", text: "Vaccinationer, læge, jordemoder og scaninger", itemsCount: 0)
            LexiconCardVStack(title: "Undersøgelser", text: "Vaccinationer, læge, jordemoder og scaninger", itemsCount: 1)
            LexiconCardVStack(title: "Undersøgelser", text: "Følg med i din graviditet hver uge", itemsCount: 2)
        }
    }
}
