// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct LexiconListHeaderView: View {
    let title: String
    let text: String
    let imageUrl: URL

    var body: some View {
        VStack {
            InnerShadowCircleView {
                ZStack {
                    CircleContentShadowView()
                        .frame(size: 72)
                    URLImage(url: imageUrl,
                             imageView: { uiImage in
                                Image(uiImage: uiImage)
                                    .resizable()
                                    .aspectRatio(contentMode: .fit)
                                    .frame(size: 56)

                             },
                             placeholderView: { ActivityIndicatorView(isAnimating: true, style: .medium, hidesWhenStopped: true) },
                             errorView: { _ in EmptyView() })
                }
            }
            .frame(size: 95)
            Text(title)
                .applyTextStyle(fontStyle: .h1)
                .multilineTextAlignment(.center)
            Text(text)
                .applyTextStyle(fontStyle: .body)
        }
        .padding(.bottom)
    }
}

struct LexiconListHeaderView_Previews: PreviewProvider {
    static var previews: some View {
        LexiconListHeaderView(title: "Some title",
                              text: "Some more text that is an description",
                              imageUrl: URL(string: "https://via.placeholder.com/150")!)
    }
}
