// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct KnowledgeViewTopSearchView: View {
    let scrollOffset: CGFloat
    let height: CGFloat

    @Binding var searchQuery: String
    @Binding var isFocused: Bool

    var body: some View {
        VStack(spacing: 0) {
            Rectangle()
                .fill(R.color.navigationBar.color())
                .frame(height: max(0, scrollOffset)) // Pushes the view down at bounce
            VStack(spacing: 0) {
                HStack {
                    SearchBar(searchQuery: $searchQuery, isFocused: $isFocused)
                    if isFocused {
                        Button(action: {
                            searchQuery = ""
                            UIApplication.shared.endEditing()
                        }, label: {
                            Text(R.string.localizable.common_regret())
                                .applyTextStyle(fontStyle: .body, textColor: R.color.primary.color())
                        })
                    }
                }
                .padding([.leading, .trailing])
                .padding([.bottom, .top], Metrics.Spacing.searchBarTopBottomMargin)

                DefaultDivider()
            }
            .background(R.color.navigationBar.color())
            .frame(height: height)
            Spacer()
        }
    }
}

struct KnowledgeViewTopSearchView_Previews: PreviewProvider {
    static var previews: some View {
        KnowledgeViewTopSearchView(
            scrollOffset: 0,
            height: 100,
            searchQuery: .constant(""),
            isFocused: .constant(false)
        )
    }
}
