// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import Foundation
import SwiftUI

final class TabBarController: UITabBarController {
    @DI private var userContext: UserContextProtocol

    override func viewDidLoad() {
        super.viewDidLoad()

        let overviewViewControler = UIHostingController(rootView: OverviewView())
        overviewViewControler.tabBarItem = tabbarItem(
            title: R.string.localizable.bottom_navigation_title_overview(),
            image: R.image.tabbar_overview()
        )

        let knowledgeView = KnowledgeView()
            .environmentObject(KnowledgeView.EnvironmentStore())

        let knowledgeViewController = UIHostingController(rootView: knowledgeView)
        knowledgeViewController.tabBarItem = tabbarItem(
             title: R.string.localizable.bottom_navigation_title_knowledge(),
            image: R.image.tabbar_knowledge()
        )

        let appointmentViewController = UIHostingController(rootView: AppointmentsView())
        appointmentViewController.tabBarItem = tabbarItem(
            title: R.string.localizable.bottom_navigation_title_appointments(),
            image: R.image.tabbar_appointments()
        )

        let journalViewController = UIHostingController(rootView: JournalView())
        journalViewController.tabBarItem = tabbarItem(
            title: R.string.localizable.bottom_navigation_title_journal(),
            image: R.image.tabbar_journal()
        )

        let moreViewController = UIHostingController(rootView: MoreView())
        moreViewController.tabBarItem = tabbarItem(
            title: R.string.localizable.bottom_navigation_title_more(),
            image: R.image.tabbar_more()
        )
        if userContext.isAuthenticated {
            viewControllers = [
                overviewViewControler,
                appointmentViewController,
                knowledgeViewController,
                journalViewController,
                moreViewController
            ]
        } else {
            viewControllers = [
                knowledgeViewController
            ]
            tabBar.isHidden = true
        }
        viewControllers?.forEach({ (vc) in
            // Set `UIHostingViewController` backgrounds to navigationbar color to color the statusbar area.
            vc.view.backgroundColor = R.color.navigationBar()
            vc.extendedLayoutIncludesOpaqueBars = true
        })
        tabBar.tintColor = R.color.tabbarSelectedTint()
        tabBar.unselectedItemTintColor = R.color.tabbarDeselectedTint()
        tabBar.barTintColor = R.color.tabbarBackground()
    }

    private func tabbarItem(title: String, image: UIImage?) -> UITabBarItem {
        UITabBarItem(
            title: title,
            image: image,
            selectedImage: image
        )
    }
}
