// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import SwiftUI

class CustomButton : UIButton {

    override var isSelected: Bool {
        didSet {
            updateForState()
        }
    }

    override var isHighlighted: Bool {
        didSet {
            updateForState()
        }
    }

    override var isEnabled: Bool {
        didSet {
            updateForState()
        }
    }

    var action: (() -> Void)?

    override init(frame: CGRect) {
        super.init(frame: frame)
        internalSetup()
    }

    required init?(coder: NSCoder) {
        super.init(coder: coder)
        internalSetup()
    }

    private func internalSetup() {
        addTarget(self, action: #selector(tapped(_:)), for: .touchUpInside)
        setup()
    }

    func setup() {
        // Override
    }

    private func updateForState() {
        if !isEnabled {
            alpha = 0.5
        } else {
            alpha = isHighlighted || isSelected ? 0.8 : 1.0
        }
    }

    override func setTitle(_ title: String?, for state: UIControl.State) {
        super.setTitle(title, for: state)
        titleLabel?.font = FontStyle.button.scaledFont()
    }

    @objc func tapped(_ sender: PrimaryButton) {
        action?()
    }
}

struct SUIButton<T: CustomButton>: UIViewRepresentable {
    var title: String
    var action: (() -> Void)?

    init(_ title: String, action: (() -> Void)?) {
        self.title = title
        self.action = action
    }

    func makeUIView(context: Context) -> T {
        T()
    }

    func updateUIView(_ uiView: T, context: Context) {
        uiView.action = action
        uiView.setTitle(title, for: .normal)
    }
}
