// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct DataTableRow: View {
    let cells: [DataTableCell]
    let colorBackground: Bool

    var body: some View {
        HStack(spacing: 0) {
            ForEach(cells.indices) { (index) in
                let cell: DataTableCell = cells[index]
                Group {
                    switch cell.type {
                    case .text:
                        Text(cell.value)
                            .applyTextStyle(fontStyle: .body)
                            .frame(maxWidth: .infinity, alignment: .leading)
                    case .boldText:
                        Text(cell.value)
                            .applyTextStyle(fontStyle: .h4)
                            .frame(maxWidth: .infinity, alignment: .leading)
                    case .button(let action):
                        Button(cell.value) {
                            action(cell)
                        }
                        .font(Font(FontStyle.h4.scaledFont()))
                        .foregroundColor(R.color.infoButton.color())
                        .frame(maxWidth: .infinity, alignment: .leading)
                    }
                }
                .padding()
                .modifier(FixedWidthModifier(fixedWidth: cell.fixedWidth))

                if cells.last?.id != cell.id {
                    DefaultDivider()
                }
            }
        }
        .background(colorBackground ? R.color.tableRow.color() : Color.clear)
    }
}

private struct FixedWidthModifier: ViewModifier {
    let fixedWidth: CGFloat?
    func body(content: Content) -> some View {
        let result: AnyView
        if let fixedWidth = fixedWidth {
            result = AnyView(content.frame(width: fixedWidth))
        } else {
            result = AnyView(content.frame(maxWidth: .infinity))
        }
        return result
    }
}

struct DataTableRow_Previews: PreviewProvider {
    static var previews: some View {
        DataTableRow(cells: [
            DataTableCell(
                id: "1",
                value: "Fostermål",
                type: .button({ _ in }),
                fixedWidth: 120
            ),
            DataTableCell(
                id: "2",
                value: "45 cm",
                type: .text,
                fixedWidth: nil
            ),
            DataTableCell(
                id: "3",
                value: "50 cm",
                type: .text,
                fixedWidth: nil
            )
        ], colorBackground: true)
    }
}
