// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct TwoColumnDataTable: View {
    let rows: [[DataTableCell]]

    var body: some View {
        CompatibleVStack(alignment: .leading, spacing: 0) {
            ForEach(rows.indices) { (rowIndex) in
                let cellsForRow: [DataTableCell] = rows[rowIndex]
                DataTableRow(cells: cellsForRow, colorBackground: rowIndex % 2 == 0)
                    .tag(rowIndex)

            }
        }
    }
}

struct TwoColumnDataTable_Previews: PreviewProvider {
    static let firstColumnWidth: CGFloat = 144
    static var previews: some View {
        TwoColumnDataTable(
            rows: [
                [
                    DataTableCell(id: "1", value: "Uge", type: .text, fixedWidth: firstColumnWidth),
                    DataTableCell(id: "2", value: "14+3", type: .text, fixedWidth: nil)
                ],
                [
                    DataTableCell(id: "3", value: "Skønnet fostervægt", type: .button({ _ in }), fixedWidth: firstColumnWidth),
                    DataTableCell(id: "4", value: "1800 g", type: .text, fixedWidth: nil)
                ],
                [
                    DataTableCell(id: "5", value: "Fosters stilling", type: .button({ _ in }), fixedWidth: firstColumnWidth),
                    DataTableCell(id: "6", value: "H", type: .text, fixedWidth: nil)
                ]
            ]
        )
    }
}
