// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import XCTest
import MaternityData
@testable import MinGraviditet

class ObservationTests: XCTestCase {

    let observations = [
        Observation(
            id: UUID(),
            dateOfMeasurement: Date(timeIntervalSince1970: 0),
            values: [],
            measuredBy: "Early Person",
            enteredBy: "Early Person",
            completed: false,
            fetus: "",
            type: .bloodPressure
        ),
        Observation(
            id: UUID(),
            dateOfMeasurement: Date(timeIntervalSince1970: 1),
            values: [],
            measuredBy: "Early Person",
            enteredBy: "Early Person",
            completed: false,
            fetus: "",
            type: .bloodPressure
        ),
        Observation(
            id: UUID(),
            dateOfMeasurement: Date(timeIntervalSince1970: 0),
            values: [],
            measuredBy: "Early Person",
            enteredBy: "Early Person",
            completed: false,
            fetus: "Test Fetus 1",
            type: .fetusActivity
        ),
        Observation(
            id: UUID(),
            dateOfMeasurement: Date(timeIntervalSince1970: 0),
            values: [],
            measuredBy: "Early Person",
            enteredBy: "Early Person",
            completed: false,
            fetus: "Test Fetus 1",
            type: .fetusPresentation
        ),
        Observation(
            id: UUID(),
            dateOfMeasurement: Date(timeIntervalSince1970: 0),
            values: [],
            measuredBy: "Early Person",
            enteredBy: "Early Person",
            completed: false,
            fetus: "Test Fetus 2",
            type: .fetusActivity
        )
    ]

    func testLatestChange() throws {
        XCTAssertEqual(observations.latestChange?.dateOfMeasurement, Date(timeIntervalSince1970: 1))
    }

    func testMotherObservations() {
        XCTAssertEqual(observations.motherObservations.count, 2)
        XCTAssertFalse(observations.motherObservations.contains(where: { $0.type.rawValue.hasPrefix("fetus_") }))
    }

    func testFetusObservations() {
        XCTAssertEqual(observations.fetusesObservations.count, 2) // Two fetuses
        XCTAssertEqual(observations.fetusesObservations.flatMap({ $0 }).count, 3) // Three values for the two fetuses
        XCTAssertTrue(observations.fetusesObservations.flatMap({ $0 }).contains(where: { $0.type.rawValue.hasPrefix("fetus_") }))
    }

}
