// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "Services",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        .library(
            name: "ChecklistServices",
            targets: ["ChecklistServices"]
        ),
        .library(
            name: "CMSServices",
            targets: ["CMSServices"]
        ),
        .library(
            name: "ConfigurationServices",
            targets: ["ConfigurationServices"]
        ),
        .library(
            name: "LexiconServices",
            targets: ["LexiconServices"]
        ),
        .library(
            name: "MaternityServices",
            targets: ["MaternityServices"]
        ),
        .library(
            name: "SharedServices",
            targets: ["SharedServices"]
        ),
        .library(
            name: "UserSettingsServices",
            targets: ["UserSettingsServices"]
        )
    ],
    dependencies: [
        .package(path: "../Data"),
        .package(path: "../Logger"),
        .package(path: "../HTTPNetworking"),
        .package(path: "../DependencyInjection")
    ],
    targets: [
        .target(
            name: "ChecklistServices",
            dependencies: [
                .product(name: "ChecklistData", package: "Data"),
                .product(name: "ErrorData", package: "Data"),
                .byName(name: "HTTPNetworking"),
                .byName(name: "SharedServices"),
            ],
            path: "Sources/Checklist"
        ),
        .target(
            name: "CMSServices",
            dependencies: [
                .product(name: "CMSData", package: "Data"),
                .product(name: "ErrorData", package: "Data"),
                .byName(name: "HTTPNetworking"),
                .byName(name: "SharedServices"),
            ],
            path: "Sources/CMS"
        ),
        .target(
            name: "ConfigurationServices",
            dependencies: [
                .product(name: "ConfigurationData", package: "Data"),
                .product(name: "ErrorData", package: "Data"),
                .byName(name: "HTTPNetworking")
            ],
            path: "Sources/Configuration"
        ),
        .target(
            name: "LexiconServices",
            dependencies: [
                .product(name: "LexiconData", package: "Data"),
                .product(name: "ErrorData", package: "Data"),
                .byName(name: "DependencyInjection"),
                .byName(name: "HTTPNetworking"),
                .byName(name: "SharedServices"),
            ],
            path: "Sources/Lexicon"
        ),
        .target(
            name: "MaternityServices",
            dependencies: [
                .product(name: "MaternityData", package: "Data"),
                .product(name: "ErrorData", package: "Data"),
                .byName(name: "HTTPNetworking"),
                .byName(name: "SharedServices")
            ],
            path: "Sources/Maternity"
        ),
        .target(
            name: "SharedServices",
            dependencies: [
                .byName(name: "HTTPNetworking"),
                .product(name: "ErrorData", package: "Data"),
                .byName(name: "Logger"),
                .byName(name: "DependencyInjection")
            ],
            path: "Sources/Shared"
        ),
        .target(
            name: "UserSettingsServices",
            dependencies: [],
            path: "Sources/UserSettings"
        ),
        // MARK: -
//        .testTarget(
//            name: "ChecklistServicesTests",
//            dependencies: ["ChecklistServices"],
//            path: "Tests/ChecklistTests"
//        ),
//        .testTarget(
//            name: "ConfigurationServicesTests",
//            dependencies: ["ConfigurationServices"],
//            path: "Tests/ConfigurationTests"
//        ),
//        .testTarget(
//            name: "LexiconServicesTests",
//            dependencies: ["LexiconServices"],
//            path: "Tests/LexiconTests"
//        ),
//        .testTarget(
//            name: "MaternityServicesTests",
//            dependencies: ["MaternityServices"],
//            path: "Tests/MaternityTests"
//        ),
        .testTarget(
            name: "SharedServicesTests",
            dependencies: ["SharedServices"],
            path: "Tests/SharedTests"
        ),
        .testTarget(
            name: "UserSettingsServicesTests",
            dependencies: ["UserSettingsServices"],
            path: "Tests/UserSettingsTests"
        ),
    ]
)
