// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import LexiconData
import ErrorData
import Combine
import SharedServices

final public class MockLexiconService: LexiconService {
    public init() { }

    public func fetchCategories() -> AnyPublisher<[LexiconData.Category], ServiceError> {
        let categories = [
            LexiconData.Category(id: UUID().uuidString,
                                 imageUrl: URL(string: "https://via.placeholder.com/150")!,
                                        name: "Uge for uge",
                                        description: "Some description",
                                        count: 4),
            LexiconData.Category(id: UUID().uuidString,
                                        imageUrl: URL(string: "https://via.placeholder.com/150")!,
                                        name: "Sundhed",
                                        description: "Some description",
                                        count: 10),
            LexiconData.Category(id: UUID().uuidString,
                                        imageUrl: URL(string: "https://via.placeholder.com/150")!,
                                        name: "Undersøgelser",
                                        description: "Some description",
                                        count: 2)
        ]

        return MockPublisher.mockFailable(
            value: categories,
            error: ServiceError.unexpectedError(MockError.randomFail)
        )
    }

    public func fetchLexicons(categories: [LexiconData.Category], searchQuery: String?) -> AnyPublisher<[Lexicon], ServiceError> {
        let lexicon = Lexicon(publicationDate: Date(),
                              lastUpdateDate: Date(),
                              id: UUID().uuidString,
                              title: "Sundhed",
                              content: [
                                Article(title: "Spis som et Y",
                                        content: "<p>Her er en lille guide med indhold</p><video width=\"320\" height=\"240\" controls>    <source src=\"movie.mp4\" type=\"video/mp4\">    <source src=\"movie.ogg\" type=\"video/ogg\">        Din browser understøtter ikke video</video><p>Der er også tekst efter videoen</p>"),
                                Article(title: "Spis som et Y",
                                        content: "<p>Her er en lille guide med indhold</p><video width=\"320\" height=\"240\" controls>    <source src=\"movie.mp4\" type=\"video/mp4\">    <source src=\"movie.ogg\" type=\"video/ogg\">        Din browser understøtter ikke video</video><p>Der er også tekst efter videoen</p>")
                              ],
                              excerpt: "Er der noget bedre tidspunkt at begynde at spise sundere, end når du er gravid? At spise sundt hjælper til at fremme en sund graviditet og en god start i livet godt tåle at kaste et kritisk blik på vores spisevaner: Er der mon noget der kan gøres bedre?",
                              categories: [],
                              tags: [])

        return MockPublisher.mockFailable(
            value: [lexicon].filter({ $0.title.contains(searchQuery ?? "") }),
            error: ServiceError.unexpectedError(MockError.randomFail)
        )
    }
}
